@@ -26,13 +26,7 @@ repair of the internal file links
 For the command line version of this tool, see the :code:`cp` tool in the docs
 for the :ref:`Python Command Line Interface <python_cli>`.
 
-References
-----------
-.. [1] Pernet, C.R., Appelhoff, S., Gorgolewski, K.J. et al. EEG-BIDS, an
-       extension to the brain imaging data structure for
-       electroencephalography. Sci Data 6, 103 (2019).
-       https://doi.org/10.1038/s41597-019-0104-8
-.. _BrainVision data format: https://www.brainproducts.com/productdetails.php?id=21&tab=5
+.. _BrainVision data format: https://www.brainproducts.com/support-resources/brainvision-core-data-format-1-0/
 """  # noqa:E501
 
 # Authors: Stefan Appelhoff <stefan.appelhoff@mailbox.org>
@@ -93,10 +87,17 @@ raw_renamed = mne.io.read_raw_brainvision(vhdr_file_renamed)
 # -------------------
 #
 # For converting data files, or writing new data to the BrainVision format, you
-# can use the `pybv`_ Python package.
+# can use :mod:`mne.export` or have a look at the `pybv`_ Python package.
 #
 # There is node JS tool to check the integrity of your BrainVision files.
 # For that, see the `BrainVision Validator <bv-validator_>`_
 #
 # .. _`pybv`: https://github.com/bids-standard/pybv
 # .. _`bv-validator`: https://github.com/sappelhoff/brainvision-validator
+#
+# References
+# ----------
+# .. [1] Pernet, C.R., Appelhoff, S., Gorgolewski, K.J. et al. EEG-BIDS, an
+#        extension to the brain imaging data structure for
+#        electroencephalography. Sci Data 6, 103 (2019).
+#        https://doi.org/10.1038/s41597-019-0104-8
