@@ -1,6 +1,6 @@
 """MNE software for easily interacting with BIDS compatible datasets."""
 
-__version__ = '0.10'
+__version__ = '0.11.1'
 from mne_bids import commands
 from mne_bids.report import make_report
 from mne_bids.path import (BIDSPath, get_datatypes, get_entity_vals,
@@ -14,4 +14,5 @@ from mne_bids.write import (make_dataset_description, write_anat,
                             get_anat_landmarks, anonymize_dataset)
 from mne_bids.sidecar_updates import update_sidecar_json, update_anat_landmarks
 from mne_bids.inspect import inspect_dataset
-from mne_bids.dig import template_to_head
+from mne_bids.dig import (template_to_head, convert_montage_to_ras,
+                          convert_montage_to_mri)
