@@ -3,7 +3,9 @@ from mne import io
 from mne.io.constants import FIFF
 
 
-BIDS_VERSION = "1.6.0"
+BIDS_VERSION = "1.7.0"
+
+PYBV_VERSION = "0.7.3"
 
 DOI = """https://doi.org/10.21105/joss.01896"""
 
@@ -29,7 +31,7 @@ ORIENTATION = {
     '.sqd': 'KitYokogawa',
 }
 
-UNITS = {
+EXT_TO_UNIT_MAP = {
     '.con': 'm',
     '.ds': 'cm',
     '.fif': 'm',
@@ -37,6 +39,10 @@ UNITS = {
     '.sqd': 'm'
 }
 
+UNITS_MNE_TO_BIDS_MAP = {
+    'C': 'oC',  # temperature in deg. C
+}
+
 meg_manufacturers = {
     '.con': 'KIT/Yokogawa',
     '.ds': 'CTF',
@@ -46,15 +52,17 @@ meg_manufacturers = {
     '.sqd': 'KIT/Yokogawa'
 }
 
-eeg_manufacturers = {'.vhdr': 'BrainProducts', '.eeg': 'BrainProducts',
+eeg_manufacturers = {'.vhdr': 'Brain Products', '.eeg': 'Brain Products',
                      '.edf': 'n/a', '.EDF': 'n/a', '.bdf': 'Biosemi',
                      '.BDF': 'Biosemi',
                      '.set': 'n/a', '.fdt': 'n/a',
                      '.lay': 'Persyst', '.dat': 'Persyst',
                      '.EEG': 'Nihon Kohden',
-                     '.cnt': 'Neuroscan', '.CNT': 'Neuroscan'}
+                     '.cnt': 'Neuroscan', '.CNT': 'Neuroscan',
+                     '.bin': 'EGI',
+                     '.cdt': 'Curry'}
 
-ieeg_manufacturers = {'.vhdr': 'BrainProducts', '.eeg': 'BrainProducts',
+ieeg_manufacturers = {'.vhdr': 'Brain Products', '.eeg': 'Brain Products',
                       '.edf': 'n/a', '.EDF': 'n/a', '.set': 'n/a',
                       '.fdt': 'n/a', '.mef': 'n/a', '.nwb': 'n/a',
                       '.lay': 'Persyst', '.dat': 'Persyst',
@@ -71,7 +79,9 @@ reader = {'.con': io.read_raw_kit, '.sqd': io.read_raw_kit,
           '.set': io.read_raw_eeglab, '.lay': io.read_raw_persyst,
           '.EEG': io.read_raw_nihon,
           '.cnt': io.read_raw_cnt, '.CNT': io.read_raw_cnt,
-          '.snirf': io.read_raw_snirf}
+          '.bin': io.read_raw_egi,
+          '.snirf': io.read_raw_snirf,
+          '.cdt': io.read_raw_curry}
 
 
 # Merge the manufacturer dictionaries in a python2 / python3 compatible way
@@ -122,7 +132,7 @@ ALLOWED_DATATYPE_EXTENSIONS = {
 ALLOWED_INPUT_EXTENSIONS = \
     allowed_extensions_meg + allowed_extensions_eeg + \
     allowed_extensions_ieeg + allowed_extensions_nirs + \
-    ['.lay', '.EEG', '.cnt', '.CNT']
+    ['.lay', '.EEG', '.cnt', '.CNT', '.bin', '.cdt']
 
 # allowed suffixes (i.e. last "_" delimiter in the BIDS filenames before
 # the extension)
@@ -151,16 +161,16 @@ ALLOWED_FILENAME_EXTENSIONS = (
     ['.mrk']  # KIT/Yokogawa/Ricoh marker coil
 )
 
-# allowed BIDS path entities
+# allowed BIDSPath entities
 ALLOWED_PATH_ENTITIES = ('subject', 'session', 'task', 'run',
                          'processing', 'recording', 'space',
-                         'acquisition', 'split',
+                         'acquisition', 'split', 'description',
                          'suffix', 'extension')
 ALLOWED_PATH_ENTITIES_SHORT = {'sub': 'subject', 'ses': 'session',
                                'task': 'task', 'acq': 'acquisition',
                                'run': 'run', 'proc': 'processing',
                                'space': 'space', 'rec': 'recording',
-                               'split': 'split'}
+                               'split': 'split', 'desc': 'description'}
 
 # Annotations to never remove during reading or writing
 ANNOTATIONS_TO_KEEP = ('BAD_ACQ_SKIP',)
@@ -242,8 +252,9 @@ ENTITY_VALUE_TYPE = {
     'space': 'label',
     'acquisition': 'label',
     'split': 'index',
+    'description': 'label',
     'suffix': 'label',
-    'extension': 'label'
+    'extension': 'label',
 }
 
 # mapping from supported BIDs coordinate frames -> MNE
@@ -254,7 +265,7 @@ BIDS_TO_MNE_FRAMES = {
     'ElektaNeuromag': 'head',
     'ChietiItab': 'head',
     'CapTrak': 'head',
-    'ACPC': 'mri',  # assumes T1 is ACPC-aligned, if not the coordinates are lost  # noqa
+    'ACPC': 'ras',  # assumes T1 is ACPC-aligned, if not the coordinates are lost  # noqa
     'fsaverage': 'mni_tal',  # XXX: note fsaverage and MNI305 are the same  # noqa
     'MNI305': 'mni_tal'
 }
