@@ -29,6 +29,7 @@ from mne.utils import logger, verbose, warn
 
 from mne_bids.path import BIDSPath, _parse_ext, _mkdir_p
 from mne_bids.utils import _get_mrk_meas_date, _check_anonymize
+import numpy as np
 
 
 def _copytree(src, dst, **kwargs):
@@ -73,7 +74,7 @@ def _get_brainvision_encoding(vhdr_file):
 
 
 def _get_brainvision_paths(vhdr_path):
-    """Get the .eeg and .vmrk file paths from a BrainVision header file.
+    """Get the .eeg/.dat and .vmrk file paths from a BrainVision header file.
 
     Parameters
     ----------
@@ -83,7 +84,7 @@ def _get_brainvision_paths(vhdr_path):
     Returns
     -------
     paths : tuple
-        Paths to the .eeg file at index 0 and the .vmrk file at index 1 of
+        Paths to the .eeg/.dat file at index 0 and the .vmrk file at index 1 of
         the returned tuple.
 
     """
@@ -100,10 +101,11 @@ def _get_brainvision_paths(vhdr_path):
     with open(vhdr_path, 'r', encoding=enc) as f:
         lines = f.readlines()
 
-    # Try to find data file .eeg
-    eeg_file_match = re.search(r'DataFile=(.*\.eeg)', ' '.join(lines))
+    # Try to find data file .eeg/.dat
+    eeg_file_match = re.search(r'DataFile=(.*\.(eeg|dat))', ' '.join(lines))
+
     if not eeg_file_match:
-        raise ValueError('Could not find a .eeg file link in'
+        raise ValueError('Could not find a .eeg or .dat file link in'
                          f' {vhdr_path}')
     else:
         eeg_file = eeg_file_match.groups()[0]
@@ -154,15 +156,15 @@ def copyfile_ctf(src, dest):
     """
     _copytree(src, dest)
     # list of file types to rename
-    file_types = ('.acq', '.eeg', '.hc', '.hist', '.infods', '.bak',
+    file_types = ('.acq', '.eeg', '.dat', '.hc', '.hist', '.infods', '.bak',
                   '.meg4', '.newds', '.res4')
     # Rename files in dest with the name of the dest directory
     fnames = [f for f in os.listdir(dest) if f.endswith(file_types)]
     bids_folder_name = op.splitext(op.split(dest)[-1])[0]
     for fname in fnames:
         ext = op.splitext(fname)[-1]
-        os.rename(op.join(dest, fname),
-                  op.join(dest, bids_folder_name + ext))
+        os.replace(op.join(dest, fname),
+                   op.join(dest, bids_folder_name + ext))
 
 
 def copyfile_kit(src, dest, subject_id, session_id,
@@ -266,10 +268,11 @@ def _anonymize_brainvision(vhdr_file, date):
 def copyfile_brainvision(vhdr_src, vhdr_dest, anonymize=None, verbose=None):
     """Copy a BrainVision file triplet to a new location and repair links.
 
-    The BrainVision file format consists of three files: .vhdr, .eeg, and .vmrk
-    The .eeg and .vmrk files associated with the .vhdr file will be given names
-    as in `vhdr_dest` with adjusted extensions. Internal file pointers will be
-    fixed.
+    The BrainVision file format consists of three files:
+    .vhdr, .eeg/.dat, and .vmrk
+    The .eeg/.dat and .vmrk files associated with the .vhdr file will be
+    given names as in `vhdr_dest` with adjusted extensions. Internal file
+    pointers will be fixed.
 
     Parameters
     ----------
@@ -319,17 +322,27 @@ def copyfile_brainvision(vhdr_src, vhdr_dest, anonymize=None, verbose=None):
     # extract encoding from brainvision header file, or default to utf-8
     enc = _get_brainvision_encoding(vhdr_src)
 
-    # Copy data .eeg ... no links to repair
+    # raise warning if binary file has .dat extension
+    if '.dat' in eeg_file_path:
+        warn("The file extension of your binary EEG data file is .dat, while "
+             "the expected extension for raw data is .eeg. "
+             "This might imply it's preprocessed or processed data: "
+             "We copied the files and changed the extension to .eeg, "
+             "but please ensure that this is actually BIDS compatible data!")
+
+    # Copy data .eeg/.dat ... no links to repair
     sh.copyfile(eeg_file_path, fname_dest + '.eeg')
 
     # Write new header and marker files, fixing the file pointer links
     # For that, we need to replace an old "basename" with a new one
-    # assuming that all .eeg, .vhdr, .vmrk share one basename
+    # assuming that all .eeg/.dat, .vhdr, .vmrk share one basename
     __, basename_src = op.split(fname_src)
-    assert basename_src + '.eeg' == op.split(eeg_file_path)[-1]
+    assert op.split(eeg_file_path)[-1] in [
+        basename_src + '.eeg', basename_src + '.dat']
     assert basename_src + '.vmrk' == op.split(vmrk_file_path)[-1]
     __, basename_dest = op.split(fname_dest)
     search_lines = ['DataFile=' + basename_src + '.eeg',
+                    'DataFile=' + basename_src + '.dat',
                     'MarkerFile=' + basename_src + '.vmrk']
 
     with open(vhdr_src, 'r', encoding=enc) as fin:
@@ -483,12 +496,11 @@ def copyfile_edf(src, dest, anonymize=None):
 
 
 def copyfile_eeglab(src, dest):
-    """Copy a EEGLAB files to a new location and adjust pointer to '.fdt' file.
+    """Copy an EEGLAB file to a new location.
 
-    Some EEGLAB .set files come with a .fdt binary file that contains the data.
-    When moving a .set file, we need to check for an associated .fdt file and
-    move it to an appropriate location as well as update an internal pointer
-    within the .set file.
+    If the EEGLAB ``.set`` file comes with an accompanying ``.fdt`` binary file
+    that contains the actual data, this function will copy this file, too, and
+    update all internal pointers in the new ``.set`` file.
 
     Parameters
     ----------
@@ -517,27 +529,40 @@ def copyfile_eeglab(src, dest):
                          f' but got {ext_src}, {ext_dest}')
 
     # Load the EEG struct
+    # NOTE: do *not* simplify cells, because this changes the underlying
+    # structure and potentially breaks re-reading of the file
     uint16_codec = None
-    eeg = loadmat(file_name=src, simplify_cells=True,
+    eeg = loadmat(file_name=src, simplify_cells=False,
                   appendmat=False, uint16_codec=uint16_codec)
     oldstyle = False
     if 'EEG' in eeg:
         eeg = eeg['EEG']
         oldstyle = True
 
-    if isinstance(eeg['data'], str):
+    try:
         # If the data field is a string, it points to a .fdt file in src dir
-        fdt_fname = eeg['data']
-        assert fdt_fname.endswith('.fdt')
-        head, tail = op.split(src)
+        if isinstance(eeg['data'][0, 0][0], str):
+            has_fdt_link = True
+    except IndexError:
+        has_fdt_link = False
+
+    if has_fdt_link:
+        fdt_fname = eeg['data'][0, 0][0]
+
+        assert fdt_fname.endswith('.fdt'), f'Unexpected fdt name: {fdt_fname}'
+        head, _ = op.split(src)
         fdt_path = op.join(head, fdt_fname)
 
         # Copy the .fdt file and give it a new name
-        sh.copyfile(fdt_path, fname_dest + '.fdt')
+        fdt_name_new = fname_dest + '.fdt'
+        sh.copyfile(fdt_path, fdt_name_new)
 
         # Now adjust the pointer in the .set file
-        head, tail = op.split(fname_dest + '.fdt')
-        eeg['data'] = tail
+        # NOTE: Clunky numpy code is to match MATLAB structure for "savemat"
+        _, tail = op.split(fdt_name_new)
+        new_value = np.empty((1, 1), dtype=object)
+        new_value[0, 0] = np.atleast_1d(np.array(tail))
+        eeg['data'] = new_value
 
         # Save the EEG dictionary as a Matlab struct again
         mdict = dict(EEG=eeg) if oldstyle else eeg
