@@ -2,29 +2,32 @@
 # Authors: Stefan Appelhoff <stefan.appelhoff@mailbox.org>
 #
 # License: BSD-3-Clause
+from contextlib import nullcontext
 import json
 import os
 import os.path as op
-import pathlib
+from pathlib import Path
 from datetime import datetime, timezone
+from typing import OrderedDict
 
 import pytest
 import shutil as sh
 import numpy as np
 from numpy.testing import assert_almost_equal
 
+from pkg_resources import parse_version
+
 import mne
+from mne.datasets import testing
 from mne.io.constants import FIFF
 from mne.utils import requires_nibabel, object_diff, requires_version
-from mne.utils import assert_dig_allclose
-from mne.datasets import testing, somato
+from mne.utils import assert_dig_allclose, check_version
 
 from mne_bids import BIDSPath
 from mne_bids.config import (MNE_STR_TO_FRAME, BIDS_SHARED_COORDINATE_FRAMES,
                              BIDS_TO_MNE_FRAMES)
-from mne_bids.read import (read_raw_bids,
-                           _read_raw, get_head_mri_trans,
-                           _handle_events_reading)
+from mne_bids.read import (read_raw_bids, _read_raw, get_head_mri_trans,
+                           _handle_events_reading, _handle_scans_reading)
 from mne_bids.tsv_handler import _to_tsv, _from_tsv
 from mne_bids.utils import (_write_json)
 from mne_bids.sidecar_updates import _update_sidecar
@@ -37,6 +40,7 @@ session_id = '01'
 run = '01'
 acq = '01'
 task = 'testing'
+fids_added = check_version('mne', '1.2')
 
 _bids_path = BIDSPath(
     subject=subject_id, session=session_id, run=run, acquisition=acq,
@@ -45,18 +49,17 @@ _bids_path = BIDSPath(
 _bids_path_minimal = BIDSPath(subject=subject_id, task=task)
 
 # Get the MNE testing sample data - USA
-data_path = testing.data_path()
+data_path = testing.data_path(download=False)
 raw_fname = op.join(data_path, 'MEG', 'sample',
                     'sample_audvis_trunc_raw.fif')
 
-# Get the MNE somato data - EU
-somato_path = somato.data_path()
-somato_raw_fname = op.join(somato_path, 'sub-01', 'meg',
-                           'sub-01_task-somato_meg.fif')
-
 # Data with cHPI info
 raw_fname_chpi = op.join(data_path, 'SSS', 'test_move_anon_raw.fif')
 
+# Tiny BIDS testing dataset
+mne_bids_root = Path(mne_bids.__file__).parents[1]
+tiny_bids_root = mne_bids_root / "mne_bids" / "tests" / "data" / "tiny_bids"
+
 warning_str = dict(
     channel_unit_changed='ignore:The unit for chann*.:RuntimeWarning:mne',
     meas_date_set_to_none="ignore:.*'meas_date' set to None:RuntimeWarning:"
@@ -111,6 +114,7 @@ def test_read_correct_inputs():
 
 
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_read_participants_data(tmp_path):
     """Test reading information from a BIDS sidecar.json file."""
     bids_path = _bids_path.copy().update(root=tmp_path, datatype='meg')
@@ -121,13 +125,15 @@ def test_read_participants_data(tmp_path):
     subject_info = {
         'hand': 1,
         'sex': 2,
+        'weight': 70.5,
+        'height': 180.5
     }
     raw.info['subject_info'] = subject_info
     write_raw_bids(raw, bids_path, overwrite=True, verbose=False)
     raw = read_raw_bids(bids_path=bids_path)
-    print(raw.info['subject_info'])
     assert raw.info['subject_info']['hand'] == 1
-    assert raw.info['subject_info']['sex'] == 2
+    assert raw.info['subject_info']['weight'] == 70.5
+    assert raw.info['subject_info']['height'] == 180.5
     assert raw.info['subject_info'].get('birthday', None) is None
     assert raw.info['subject_info']['his_id'] == f'sub-{bids_path.subject}'
     assert 'participant_id' not in raw.info['subject_info']
@@ -140,25 +146,35 @@ def test_read_participants_data(tmp_path):
     raw = read_raw_bids(bids_path=bids_path)
     assert raw.info['subject_info']['hand'] == 0
     assert raw.info['subject_info']['sex'] == 2
+    assert raw.info['subject_info']['weight'] == 70.5
+    assert raw.info['subject_info']['height'] == 180.5
     assert raw.info['subject_info'].get('birthday', None) is None
 
     # make sure things are read even if the entries don't make sense
     participants_tsv = _from_tsv(participants_tsv_fpath)
     participants_tsv['hand'][0] = 'righty'
     participants_tsv['sex'][0] = 'malesy'
+    # 'n/a' values should get omitted
+    participants_tsv['weight'] = ['n/a']
+    participants_tsv['height'] = ['tall']
+
     _to_tsv(participants_tsv, participants_tsv_fpath)
     with pytest.warns(RuntimeWarning, match='Unable to map'):
         raw = read_raw_bids(bids_path=bids_path)
-        assert raw.info['subject_info']['hand'] is None
-        assert raw.info['subject_info']['sex'] is None
 
-    # make sure to read in if no participants file
+    assert 'hand' not in raw.info['subject_info']
+    assert 'sex' not in raw.info['subject_info']
+    assert 'weight' not in raw.info['subject_info']
+    assert 'height' not in raw.info['subject_info']
+
+    # test reading if participants.tsv is missing
     raw = _read_raw_fif(raw_fname, verbose=False)
     write_raw_bids(raw, bids_path, overwrite=True, verbose=False)
-    os.remove(participants_tsv_fpath)
+    participants_tsv_fpath.unlink()
     with pytest.warns(RuntimeWarning, match='participants.tsv file not found'):
         raw = read_raw_bids(bids_path=bids_path)
-        assert raw.info['subject_info'] is None
+
+    assert raw.info['subject_info'] == dict()
 
 
 @pytest.mark.parametrize(
@@ -170,6 +186,7 @@ def test_read_participants_data(tmp_path):
      ('l', 2, 'm', 1)]
 )
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_read_participants_handedness_and_sex_mapping(hand_bids, hand_mne,
                                                       sex_bids, sex_mne,
                                                       tmp_path):
@@ -194,6 +211,7 @@ def test_read_participants_handedness_and_sex_mapping(hand_bids, hand_mne,
 
 @requires_nibabel()
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_get_head_mri_trans(tmp_path):
     """Test getting a trans object from BIDS data."""
     import nibabel as nib
@@ -213,7 +231,7 @@ def test_get_head_mri_trans(tmp_path):
     bids_path = _bids_path.copy().update(
         root=tmp_path, datatype='meg', suffix='meg'
     )
-    write_raw_bids(raw, bids_path, events_data=events, event_id=event_id,
+    write_raw_bids(raw, bids_path, events=events, event_id=event_id,
                    overwrite=False)
 
     # We cannot recover trans if no MRI has yet been written
@@ -270,14 +288,18 @@ def test_get_head_mri_trans(tmp_path):
     raw_test.set_montage(montage)
     raw_test.save(bids_path.fpath, overwrite=True)
 
-    with pytest.raises(RuntimeError, match='Could not extract fiducial'):
+    if fids_added:
+        ctx = nullcontext()
+    else:
+        ctx = pytest.raises(RuntimeError, match='Could not extract fiducial')
+    with ctx:
         get_head_mri_trans(bids_path=bids_path, fs_subject='sample',
                            fs_subjects_dir=subjects_dir)
 
     # test we are permissive for different casings of landmark names in the
     # sidecar, and also accept "nasion" instead of just "NAS"
     raw = _read_raw_fif(raw_fname)
-    write_raw_bids(raw, bids_path, events_data=events, event_id=event_id,
+    write_raw_bids(raw, bids_path, events=events, event_id=event_id,
                    overwrite=True)  # overwrite with new acq
     t1w_bids_path = write_anat(
         t1w_mgh, bids_path=t1w_bids_path, landmarks=landmarks, overwrite=True
@@ -429,6 +451,7 @@ def test_get_head_mri_trans(tmp_path):
     write_raw_bids(raw=raw, bids_path=bids_path, verbose=False)
 
 
+@testing.requires_testing_data
 def test_handle_events_reading(tmp_path):
     """Test reading events from a BIDS events.tsv file."""
     # We can use any `raw` for this
@@ -494,6 +517,7 @@ def test_handle_events_reading(tmp_path):
 
 
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_keep_essential_annotations(tmp_path):
     """Test that essential Annotations are not omitted during I/O roundtrip."""
     raw = _read_raw_fif(raw_fname)
@@ -516,6 +540,7 @@ def test_keep_essential_annotations(tmp_path):
 
 
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_handle_scans_reading(tmp_path):
     """Test reading data from a BIDS scans.tsv file."""
     raw = _read_raw_fif(raw_fname)
@@ -556,7 +581,42 @@ def test_handle_scans_reading(tmp_path):
     assert new_acq_time != raw_01.info['meas_date']
 
 
+@requires_version('mne', '1.2')  # tiny_bids contains GSR & temperature chans
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+def test_handle_scans_reading_brainvision(tmp_path):
+    """Test stability of BrainVision's different file extensions"""
+    test_scan_eeg = OrderedDict(
+        [('filename', [Path('eeg/sub-01_ses-eeg_task-rest_eeg.eeg')]),
+         ('acq_time', ['2000-01-01T12:00:00.000000Z'])]
+    )
+    test_scan_vmrk = OrderedDict(
+        [('filename', [Path('eeg/sub-01_ses-eeg_task-rest_eeg.vmrk')]),
+         ('acq_time', ['2000-01-01T12:00:00.000000Z'])]
+    )
+    test_scan_edf = OrderedDict(
+        [('filename', [Path('eeg/sub-01_ses-eeg_task-rest_eeg.edf')]),
+         ('acq_time', ['2000-01-01T12:00:00.000000Z'])]
+    )
+    os.mkdir(tmp_path / 'eeg')
+    for test_scan in [test_scan_eeg, test_scan_vmrk, test_scan_edf]:
+        _to_tsv(test_scan, tmp_path / test_scan['filename'][0])
+
+    bids_path = BIDSPath(subject='01', session='eeg', task='rest',
+                         datatype='eeg', root=tiny_bids_root)
+
+    raw = read_raw_bids(bids_path)
+
+    for test_scan in [test_scan_eeg, test_scan_vmrk]:
+        _handle_scans_reading(tmp_path / test_scan['filename'][0],
+                              raw, bids_path)
+
+    with pytest.raises(ValueError, match="is not in list"):
+        _handle_scans_reading(tmp_path / test_scan_edf['filename'][0],
+                              raw, bids_path)
+
+
+@pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_handle_info_reading(tmp_path):
     """Test reading information from a BIDS sidecar JSON file."""
     # read in USA dataset, so it should find 50 Hz
@@ -576,7 +636,7 @@ def test_handle_info_reading(tmp_path):
     bids_fname.update(datatype=suffix)
     sidecar_fname = _find_matching_sidecar(bids_fname, suffix=suffix,
                                            extension='.json')
-    sidecar_fname = pathlib.Path(sidecar_fname)
+    sidecar_fname = Path(sidecar_fname)
 
     # assert that we get the same line frequency set
     raw = read_raw_bids(bids_path=bids_path)
@@ -584,7 +644,7 @@ def test_handle_info_reading(tmp_path):
 
     # setting line_freq to None should produce 'n/a' in the JSON sidecar
     raw.info['line_freq'] = None
-    write_raw_bids(raw, bids_path, overwrite=True)
+    write_raw_bids(raw, bids_path, overwrite=True, format="FIF")
     raw = read_raw_bids(bids_path=bids_path)
     assert raw.info['line_freq'] is None
 
@@ -594,7 +654,7 @@ def test_handle_info_reading(tmp_path):
     # 2. if line frequency is not set in raw file, then ValueError
     del raw.info['line_freq']
     with pytest.raises(ValueError, match="PowerLineFrequency .* required"):
-        write_raw_bids(raw, bids_path, overwrite=True)
+        write_raw_bids(raw, bids_path, overwrite=True, format="FIF")
 
     # check whether there are "Extra points" in raw.info['dig'] if
     # DigitizedHeadPoints is set to True and not otherwise
@@ -625,7 +685,7 @@ def test_handle_info_reading(tmp_path):
     # in addition, it should not break the sidecar reading
     # in `read_raw_bids`
     raw.info['line_freq'] = 60
-    write_raw_bids(raw, bids_path, overwrite=True)
+    write_raw_bids(raw, bids_path, overwrite=True, format="FIF")
     deriv_dir = tmp_path / 'derivatives'
     deriv_dir.mkdir()
     sidecar_copy = deriv_dir / op.basename(sidecar_fname)
@@ -642,12 +702,12 @@ def test_handle_info_reading(tmp_path):
         assert raw.info['line_freq'] == 55
 
 
-@requires_version('mne', '0.24')
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
 @pytest.mark.filterwarnings(warning_str['maxshield'])
+@testing.requires_testing_data
 def test_handle_chpi_reading(tmp_path):
     """Test reading of cHPI information."""
-    raw = _read_raw_fif(raw_fname_chpi, allow_maxshield=True)
+    raw = _read_raw_fif(raw_fname_chpi, allow_maxshield='yes')
     root = tmp_path / 'chpi'
     root.mkdir()
     bids_path = BIDSPath(subject='01', session='01',
@@ -664,33 +724,38 @@ def test_handle_chpi_reading(tmp_path):
         meg_json_data = json.load(f)
 
     # cHPI frequency mismatch
-    meg_json_data_freq_mismatch = meg_json_data.copy()
-    meg_json_data_freq_mismatch['HeadCoilFrequency'][0] = 123
-    _write_json(meg_json_path, meg_json_data_freq_mismatch, overwrite=True)
+    if parse_version(mne.__version__) <= parse_version('1.1'):
+        assert 'ContinuousHeadLocalization' not in meg_json_data
+        assert 'HeadCoilFrequency' not in meg_json_data
+    else:
+        meg_json_data_freq_mismatch = meg_json_data.copy()
+        meg_json_data_freq_mismatch['HeadCoilFrequency'][0] = 123
+        _write_json(meg_json_path, meg_json_data_freq_mismatch, overwrite=True)
+
+        with pytest.warns(RuntimeWarning,
+                          match='Defaulting to .* mne.Raw object'):
+            raw_read = read_raw_bids(bids_path)
+
+        # cHPI "off" according to sidecar, but present in the data
+        meg_json_data_chpi_mismatch = meg_json_data.copy()
+        meg_json_data_chpi_mismatch['ContinuousHeadLocalization'] = False
+        _write_json(meg_json_path, meg_json_data_chpi_mismatch, overwrite=True)
 
-    with pytest.warns(RuntimeWarning, match='Defaulting to .* mne.Raw object'):
         raw_read = read_raw_bids(bids_path)
-
-    # cHPI "off" according to sidecar, but present in the data
-    meg_json_data_chpi_mismatch = meg_json_data.copy()
-    meg_json_data_chpi_mismatch['ContinuousHeadLocalization'] = False
-    _write_json(meg_json_path, meg_json_data_chpi_mismatch, overwrite=True)
-
-    raw_read = read_raw_bids(bids_path)
-    assert raw_read.info['hpi_subsystem'] is None
-    assert raw_read.info['hpi_meas'] == []
+        assert raw_read.info['hpi_subsystem'] is None
+        assert raw_read.info['hpi_meas'] == []
 
 
 @pytest.mark.filterwarnings(warning_str['nasion_not_found'])
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_handle_eeg_coords_reading(tmp_path):
     """Test reading iEEG coordinates from BIDS files."""
     bids_path = BIDSPath(
         subject=subject_id, session=session_id, run=run, acquisition=acq,
         task=task, root=tmp_path)
 
-    data_path = op.join(testing.data_path(), 'EDF')
-    raw_fname = op.join(data_path, 'test_reduced.edf')
+    raw_fname = op.join(data_path, 'EDF', 'test_reduced.edf')
     raw = _read_raw_edf(raw_fname)
 
     # ensure we are writing 'eeg' data
@@ -699,7 +764,7 @@ def test_handle_eeg_coords_reading(tmp_path):
 
     # set a `random` montage
     ch_names = raw.ch_names
-    elec_locs = np.random.random((len(ch_names), 3)).astype(float)
+    elec_locs = np.random.RandomState(0).randn(len(ch_names), 3)
     ch_pos = dict(zip(ch_names, elec_locs))
 
     # # create montage in 'unknown' coordinate frame
@@ -707,8 +772,12 @@ def test_handle_eeg_coords_reading(tmp_path):
     montage = mne.channels.make_dig_montage(ch_pos=ch_pos,
                                             coord_frame="unknown")
     raw.set_montage(montage)
-    with pytest.raises(RuntimeError, match="'head' coordinate frame "
-                                           "must contain"):
+    if fids_added:
+        ctx = nullcontext()
+    else:
+        ctx = pytest.raises(
+            RuntimeError, match="'head' coordinate frame must contain")
+    with ctx:
         write_raw_bids(raw, bids_path, overwrite=True)
 
     bids_path.update(root=tmp_path)
@@ -720,24 +789,33 @@ def test_handle_eeg_coords_reading(tmp_path):
                                               suffix='electrodes',
                                               extension='.tsv',
                                               on_error='warn')
-    assert coordsystem_fname is None
-    assert electrodes_fname is None
+    if fids_added:
+        assert coordsystem_fname is not None
+        assert electrodes_fname is not None
+    else:
+        assert coordsystem_fname is None
+        assert electrodes_fname is None
 
     # create montage in head frame and set should result in
     # an error if landmarks are not set
     montage = mne.channels.make_dig_montage(ch_pos=ch_pos,
                                             coord_frame="head")
     raw.set_montage(montage)
-    with pytest.raises(RuntimeError, match="'head' coordinate frame "
-                                           "must contain"):
+    if fids_added:
+        ctx = nullcontext()
+    else:
+        ctx = pytest.raises(
+            RuntimeError, match="'head' coordinate frame must contain")
+    with ctx:
         write_raw_bids(raw, bids_path, overwrite=True)
 
-    montage = mne.channels.make_dig_montage(ch_pos=ch_pos,
-                                            coord_frame="head",
-                                            nasion=[1, 0, 0],
-                                            lpa=[0, 1, 0],
-                                            rpa=[0, 0, 1])
-    raw.set_montage(montage)
+    if not fids_added:  # only need to rerun if the last one failed
+        montage = mne.channels.make_dig_montage(ch_pos=ch_pos,
+                                                coord_frame="head",
+                                                nasion=[1, 0, 0],
+                                                lpa=[0, 1, 0],
+                                                rpa=[0, 0, 1])
+        raw.set_montage(montage)
     write_raw_bids(raw, bids_path, overwrite=True)
 
     # obtain the sensor positions and assert ch_coords are same
@@ -759,10 +837,10 @@ def test_handle_eeg_coords_reading(tmp_path):
                          [_bids_path, _bids_path_minimal])
 @pytest.mark.filterwarnings(warning_str['nasion_not_found'])
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_handle_ieeg_coords_reading(bids_path, tmp_path):
     """Test reading iEEG coordinates from BIDS files."""
-    data_path = op.join(testing.data_path(), 'EDF')
-    raw_fname = op.join(data_path, 'test_reduced.edf')
+    raw_fname = op.join(data_path, 'EDF', 'test_reduced.edf')
     bids_fname = bids_path.copy().update(datatype='ieeg',
                                          suffix='ieeg',
                                          extension='.edf',
@@ -776,7 +854,7 @@ def test_handle_ieeg_coords_reading(bids_path, tmp_path):
     # coordinate frames in mne-python should all map correctly
     # set a `random` montage
     ch_names = raw.ch_names
-    elec_locs = np.random.random((len(ch_names), 3)).astype(float)
+    elec_locs = np.random.RandomState(0).randn(len(ch_names), 3)
     ch_pos = dict(zip(ch_names, elec_locs))
     coordinate_frames = ['mni_tal']
     for coord_frame in coordinate_frames:
@@ -881,7 +959,7 @@ def test_handle_ieeg_coords_reading(bids_path, tmp_path):
     # ACPC should be read in as RAS for iEEG
     _update_sidecar(coordsystem_fname, 'iEEGCoordinateSystem', 'ACPC')
     raw_test = read_raw_bids(bids_path=bids_fname, verbose=False)
-    coord_frame_int = MNE_STR_TO_FRAME['mri']
+    coord_frame_int = MNE_STR_TO_FRAME['ras']
     for digpoint in raw_test.info['dig']:
         assert digpoint['coord_frame'] == coord_frame_int
 
@@ -934,11 +1012,12 @@ def test_handle_ieeg_coords_reading(bids_path, tmp_path):
 @requires_nibabel()
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
 @pytest.mark.parametrize('fname', ['testdata_ctf.ds', 'catch-alp-good-f.ds'])
+@testing.requires_testing_data
 def test_get_head_mri_trans_ctf(fname, tmp_path):
     """Test getting a trans object from BIDS data in CTF."""
     import nibabel as nib
 
-    ctf_data_path = op.join(testing.data_path(), 'CTF')
+    ctf_data_path = op.join(data_path, 'CTF')
     raw_ctf_fname = op.join(ctf_data_path, fname)
     raw_ctf = _read_raw_ctf(raw_ctf_fname, clean_names=True)
     bids_path = _bids_path.copy().update(
@@ -970,6 +1049,7 @@ def test_get_head_mri_trans_ctf(fname, tmp_path):
 
 
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_read_raw_bids_pathlike(tmp_path):
     """Test that read_raw_bids() can handle a Path-like bids_root."""
     bids_path = _bids_path.copy().update(root=tmp_path, datatype='meg')
@@ -979,6 +1059,7 @@ def test_read_raw_bids_pathlike(tmp_path):
 
 
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_read_raw_datatype(tmp_path):
     """Test that read_raw_bids() can infer the str_suffix if need be."""
     bids_path = _bids_path.copy().update(root=tmp_path, datatype='meg')
@@ -998,6 +1079,7 @@ def test_read_raw_datatype(tmp_path):
     assert raw_1 == raw_3
 
 
+@testing.requires_testing_data
 def test_handle_channel_type_casing(tmp_path):
     """Test that non-uppercase entries in the `type` column are accepted."""
     bids_path = _bids_path.copy().update(root=tmp_path)
@@ -1022,6 +1104,38 @@ def test_handle_channel_type_casing(tmp_path):
 
 
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
+def test_handle_non_mne_channel_type(tmp_path):
+    """Test that channel types not known to MNE will be read as 'misc'."""
+    bids_path = _bids_path.copy().update(root=tmp_path)
+    raw = _read_raw_fif(raw_fname, verbose=False)
+
+    write_raw_bids(raw, bids_path, overwrite=True,
+                   verbose=False)
+
+    channels_tsv_path = bids_path.copy().update(
+        root=tmp_path,
+        datatype='meg',
+        suffix='channels',
+        extension='.tsv'
+    ).fpath
+
+    channels_data = _from_tsv(channels_tsv_path)
+    # Violates BIDS, but ensures we won't have an appropriate
+    # BIDS -> MNE mapping.
+    ch_idx = -1
+    channels_data['type'][ch_idx] = 'FOOBAR'
+    _to_tsv(data=channels_data, fname=channels_tsv_path)
+
+    with pytest.warns(RuntimeWarning, match='will be set to \"misc\"'):
+        raw = read_raw_bids(bids_path)
+
+    # Should be a 'misc' channel.
+    assert raw.get_channel_types([channels_data['name'][ch_idx]]) == ['misc']
+
+
+@pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_bads_reading(tmp_path):
     bids_path = _bids_path.copy().update(root=tmp_path, datatype='meg')
     bads_raw = ['MEG 0112', 'MEG 0113']
@@ -1044,6 +1158,7 @@ def test_bads_reading(tmp_path):
 
 
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_write_read_fif_split_file(tmp_path, monkeypatch):
     """Test split files are read correctly."""
     # load raw test file, extend it to be larger than 2gb, and save it
@@ -1058,9 +1173,10 @@ def test_write_read_fif_split_file(tmp_path, monkeypatch):
     bids_path.update(acquisition='01')
     n_channels = len(raw.ch_names)
     n_times = int(2.5e6 / n_channels)  # enough to produce a 10MB split
-    data = np.empty((n_channels, n_times), dtype=np.float32)
+    data = np.random.RandomState(0).randn(
+        n_channels, n_times).astype(np.float32)
     raw = mne.io.RawArray(data, raw.info)
-    big_fif_fname = pathlib.Path(tmp_dir) / 'test_raw.fif'
+    big_fif_fname = Path(tmp_dir) / 'test_raw.fif'
 
     split_size = '10MB'
     raw.save(big_fif_fname, split_size=split_size)
@@ -1110,6 +1226,7 @@ def test_write_read_fif_split_file(tmp_path, monkeypatch):
 
 
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_ignore_exclude_param(tmp_path):
     """Test that extra_params=dict(exclude=...) is being ignored."""
     bids_path = _bids_path.copy().update(root=tmp_path)
@@ -1123,6 +1240,7 @@ def test_ignore_exclude_param(tmp_path):
 
 
 @pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+@testing.requires_testing_data
 def test_channels_tsv_raw_mismatch(tmp_path):
     """Test behavior when channels.tsv contains channels not found in raw."""
     bids_path = _bids_path.copy().update(root=tmp_path, datatype='meg',
@@ -1179,6 +1297,7 @@ def test_channels_tsv_raw_mismatch(tmp_path):
         read_raw_bids(bids_path)
 
 
+@testing.requires_testing_data
 def test_file_not_found(tmp_path):
     """Check behavior if the requested file cannot be found."""
     # First a path with a filename extension.
@@ -1194,3 +1313,25 @@ def test_file_not_found(tmp_path):
     bp.extension = None
     with pytest.raises(FileNotFoundError, match='File does not exist'):
         read_raw_bids(bids_path=bp)
+
+    bp.update(extension='.fif')
+    _read_raw_fif(raw_fname, verbose=False).save(bp.fpath)
+    with pytest.warns(RuntimeWarning, match=r'channels\.tsv'):
+        read_raw_bids(bp)  # smoke test
+
+    bp.update(task=None)
+    with pytest.raises(FileNotFoundError, match='Did you mean'):
+        read_raw_bids(bp)
+
+
+@requires_version('mne', '1.2')
+@pytest.mark.filterwarnings(warning_str['channel_unit_changed'])
+def test_gsr_and_temp_reading():
+    """Test GSR and temperature channels are handled correctly."""
+    bids_path = BIDSPath(
+        subject='01', session='eeg', task='rest', datatype='eeg',
+        root=tiny_bids_root
+    )
+    raw = read_raw_bids(bids_path)
+    assert raw.get_channel_types(['GSR']) == ['gsr']
+    assert raw.get_channel_types(['Temperature']) == ['temperature']
