@@ -17,7 +17,7 @@ import numpy as np
 from mne.channels import make_standard_montage
 from mne.io.kit.kit import get_kit_info
 from mne.io.pick import pick_types
-from mne.utils import warn, logger, verbose, check_version
+from mne.utils import warn, logger, verbose
 
 from mne_bids.tsv_handler import _to_tsv
 
@@ -66,7 +66,9 @@ def _get_ch_type_mapping(fro='mne', to='bids'):
     if fro == 'mne' and to == 'bids':
         mapping = dict(eeg='EEG', misc='MISC', stim='TRIG', emg='EMG',
                        ecog='ECOG', seeg='SEEG', eog='EOG', ecg='ECG',
-                       resp='RESP', bio='MISC', dbs='DBS',
+                       resp='RESP', bio='MISC', dbs='DBS', gsr='GSR',
+                       temperature='TEMP',
+                       # NIRS
                        fnirs_cw_amplitude='NIRSCWAMPLITUDE',
                        # MEG channels
                        meggradaxial='MEGGRADAXIAL', megmag='MEGMAG',
@@ -77,8 +79,11 @@ def _get_ch_type_mapping(fro='mne', to='bids'):
     elif fro == 'bids' and to == 'mne':
         mapping = dict(EEG='eeg', MISC='misc', TRIG='stim', EMG='emg',
                        ECOG='ecog', SEEG='seeg', EOG='eog', ECG='ecg',
-                       RESP='resp', NIRS='fnirs_cw_amplitude',
-                       # No MEG channels for now
+                       RESP='resp', GSR='gsr', TEMP='temperature',
+                       # NIRS
+                       NIRSCWAMPLITUDE='fnirs_cw_amplitude',
+                       NIRS='fnirs_cw_amplitude',
+                       # No MEG channels for now (see Notes above)
                        # Many to one mapping
                        VEOG='eog', HEOG='eog', DBS='dbs')
     else:
@@ -128,10 +133,6 @@ def _handle_datatype(raw, datatype):
         if 'eeg' in raw:
             datatypes.append('eeg')
         if 'fnirs_cw_amplitude' in raw:
-            if not check_version('mne', '1.0'):  # pragma: no cover
-                raise RuntimeError(
-                    'fNIRS support in MNE-BIDS requires MNE-Python version 1.0'
-                )
             datatypes.append('nirs')
         if len(datatypes) == 0:
             raise ValueError('No MEG, EEG or iEEG channels found in data. '
